# PTArcade
[![Anaconda-Server Badge](https://anaconda.org/conda-forge/ptarcade/badges/version.svg)](https://anaconda.org/conda-forge/ptarcade) [![PyPI version](https://badge.fury.io/py/ptarcade.svg)](https://badge.fury.io/py/ptarcade) [<img src="https://img.shields.io/badge/dockerhub-ptarcade-important.svg?logo=Docker">](https://hub.docker.com/r/ngnewphy/ptarcade) [![Anaconda-Server Badge](https://anaconda.org/conda-forge/ptarcade/badges/latest_release_date.svg)](https://anaconda.org/conda-forge/ptarcade)


PTArcade provides an interface to the ENTERPRISE analysis suite and allows for simple implementation of new-physics searches in PTA data. 

The user can specify a new physics signal (either deterministic or stochastic), and the code will output Monte Carlo chains that can be used to reconstruct the model's parameter posterior distributions. 

Please see our detailed documentation [here](https://andrea-mitridate.github.io/PTArcade/)
